from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Power_Supervisor = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'DIO705', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO705'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisor wdg', 'description':'', 'datasheet':'https://dioo.com/uploads/product/20210528/dae33bc3e6c4b6e07ca730d55ecc4c48.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nDIO705\n\nsupervisor wdg', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.PASSIVE),
            Pin(num='2',name='V_{CC}',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='PFI',func=pin_types.INPUT),
            Pin(num='5',name='~{PFO}',func=pin_types.OUTPUT),
            Pin(num='6',name='WDI',func=pin_types.INPUT),
            Pin(num='7',name='~{RESET}',func=pin_types.OUTPUT),
            Pin(num='8',name='~{WDO}',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'LM3880', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM3880'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Power Sequencer', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm3880.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nLM3880\n\nPower Sequencer', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='FLAG3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='FLAG2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='FLAG1',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM809', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM809'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'reset supervisor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm809.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nLM809\n\nreset supervisor', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM810'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'reset supervisor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm809.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nLM810\n\nreset supervisor', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RESET',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX16050xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX16050xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.6x2.6mm', 'keywords':'power sequencing', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX16050-MAX16051.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX16050xTI\n\npower sequencing', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DISC3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='DISC2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{EN_HOLD}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='REM',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='DISC1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{OV_OUT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='~{FAULT}',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DELAY',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='TIMEOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='SEQ1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SEQ2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SEQ3',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='CP_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='ABP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='DISC4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SET3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='OUT3',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX16051xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX16051xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.6x2.6mm', 'keywords':'power sequencing', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX16050-MAX16051.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX16051xTI\n\npower sequencing', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DISC3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='DISC2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{EN_HOLD}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='REM',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='DISC1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{OV_OUT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='~{FAULT}',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DELAY',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='TIMEOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='DISC5',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='27',name='SET5',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='CP_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='ABP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='DISC4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SET3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='OUT3',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6355', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6355'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Power Supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6351-MAX6360.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX6355\n\nPower Supervisor', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RSTIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC1',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6369', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6369'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-8'], 'footprint':'Package_TO_SOT_SMD:SOT-23-8', 'keywords':'watchdog supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6369-MAX6374.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX6369\n\nwatchdog supervisor', 'pins':[
            Pin(num='1',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SET0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{WDO}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6370', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6370'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-8'], 'footprint':'Package_TO_SOT_SMD:SOT-23-8', 'keywords':'watchdog supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6369-MAX6374.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX6370\n\nwatchdog supervisor', 'pins':[
            Pin(num='1',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SET0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{WDO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX691xPE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX691xPE'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'Power Supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX690-MAX695.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX691xPE\n\nPower Supervisor', 'pins':[
            Pin(num='1',name='VBATT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{PFO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CE_OUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CE_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{WDO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='RESET',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BATT_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{LOW_LINE}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OSC_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PFI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX691xWE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX691xWE'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'Power Supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX690-MAX695.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX691xWE\n\nPower Supervisor', 'pins':[
            Pin(num='1',name='VBATT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{PFO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CE_OUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CE_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{WDO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='RESET',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BATT_ON',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{LOW_LINE}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OSC_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PFI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC34064D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC34064D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Power Supervisor', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC34064-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMC34064D\n\nPower Supervisor', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC34064DM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC34064DM'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Power Supervisor', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC34064-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMC34064DM\n\nPower Supervisor', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC34064P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC34064P'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92L_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92L_Inline', 'keywords':'Power Supervisor', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC34064-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMC34064P\n\nPower Supervisor', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC34064SN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC34064SN'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-5_1.65x3.05mm_P0.95mm'], 'footprint':'Package_SO:TSOP-5_1.65x3.05mm_P0.95mm', 'keywords':'Power Supervisor', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC34064-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMC34064SN\n\nPower Supervisor', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP100-270D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP100-270D'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP100-270D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP101-270D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP101-270D'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP101-270D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP120-xxxDxTO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP120-xxxDxTO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'supervisory circuit', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP120-xxxDxTO\n\nsupervisory circuit', 'pins':[
            Pin(num='2',name='VDD',func=pin_types.PWRIN),
            Pin(num='1',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP120-xxxGxTO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP120-xxxGxTO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'supervisory circuit', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP120-xxxGxTO\n\nsupervisory circuit', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RST}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP120-xxxHxTO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP120-xxxHxTO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'supervisory circuit', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP120-xxxHxTO\n\nsupervisory circuit', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP120-xxxxSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP120-xxxxSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisory circuit', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP120-xxxxSN\n\nsupervisory circuit', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP120-xxxxTT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP120-xxxxTT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'supervisory circuit', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP120-xxxxTT\n\nsupervisory circuit', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP130-xxxFxTO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP130-xxxFxTO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'supervisory circuit pull-up', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP130-xxxFxTO\n\nsupervisory circuit pull-up', 'pins':[
            Pin(num='3',name='VDD',func=pin_types.PWRIN),
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RST}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC811LUY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC811LUY'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic811.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMIC811LUY\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCM809', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCM809'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21661E.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTCM809\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCM810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCM810'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21661E.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTCM810\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RESET',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7702A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7702A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7702A\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7705ACPSR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7705ACPSR'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-8_5.3x6.2mm_P1.27mm'], 'footprint':'Package_SO:SO-8_5.3x6.2mm_P1.27mm', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7705ACPSR\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS3430WDRC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS3430WDRC'}), 'ref_prefix':'U', 'fplist':['Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.65x2.4mm'], 'footprint':'Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.65x2.4mm', 'keywords':'watchdog supervisor', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/TPS3430', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTPS3430WDRC\n\nwatchdog supervisor', 'pins':[
            Pin(num='10',name='VDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='VDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CWD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SET0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CRST',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{WDO}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS3702', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS3702'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'protection overvoltage unvervoltage monitor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps3702.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTPS3702\n\nprotection overvoltage unvervoltage monitor', 'pins':[
            Pin(num='1',name='UV',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SET',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OV',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS3808DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS3808DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'supply voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps3808.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTPS3808DBV\n\nsupply voltage supervisor', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS3831', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS3831'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_X2SON-4_1x1mm_P0.65mm'], 'footprint':'Package_SON:Texas_X2SON-4_1x1mm_P0.65mm', 'keywords':'supply voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/sbvs193d/sbvs193d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTPS3831\n\nsupply voltage supervisor', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS3839DBZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS3839DBZ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'supply voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/sbvs193d/sbvs193d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTPS3839DBZ\n\nsupply voltage supervisor', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS3839DQN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS3839DQN'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_X2SON-4_1x1mm_P0.65mm'], 'footprint':'Package_SON:Texas_X2SON-4_1x1mm_P0.65mm', 'keywords':'supply voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/sbvs193d/sbvs193d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTPS3839DQN\n\nsupply voltage supervisor', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TP',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAT811JTBI-GT3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAT811JTBI-GT3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/CAT811-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nCAT811JTBI-GT3\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAT811LTBI-GT3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAT811LTBI-GT3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/CAT811-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nCAT811LTBI-GT3\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAT811MTBI-GT3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAT811MTBI-GT3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/CAT811-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nCAT811MTBI-GT3\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAT811RTBI-GT3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAT811RTBI-GT3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/CAT811-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nCAT811RTBI-GT3\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAT811STBI-GT3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAT811STBI-GT3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/CAT811-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nCAT811STBI-GT3\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAT811TTBI-GT3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAT811TTBI-GT3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/CAT811-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nCAT811TTBI-GT3\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAT811ZTBI-GT3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAT811ZTBI-GT3'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/CAT811-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nCAT811ZTBI-GT3\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO706', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO706'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisor wdg', 'description':'', 'datasheet':'https://dioo.com/uploads/product/20210528/dae33bc3e6c4b6e07ca730d55ecc4c48.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nDIO706\n\nsupervisor wdg', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.PASSIVE),
            Pin(num='2',name='V_{CC}',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='PFI',func=pin_types.INPUT),
            Pin(num='5',name='~{PFO}',func=pin_types.OUTPUT),
            Pin(num='6',name='WDI',func=pin_types.INPUT),
            Pin(num='7',name='~{RESET}',func=pin_types.OUTPUT),
            Pin(num='8',name='~{WDO}',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO706J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO706J'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisor wdg', 'description':'', 'datasheet':'https://dioo.com/uploads/product/20210528/dae33bc3e6c4b6e07ca730d55ecc4c48.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nDIO706J\n\nsupervisor wdg', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.PASSIVE),
            Pin(num='2',name='V_{CC}',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='PFI',func=pin_types.INPUT),
            Pin(num='5',name='~{PFO}',func=pin_types.OUTPUT),
            Pin(num='6',name='WDI',func=pin_types.INPUT),
            Pin(num='7',name='~{RESET}',func=pin_types.OUTPUT),
            Pin(num='8',name='~{WDO}',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO706R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO706R'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisor wdg', 'description':'', 'datasheet':'https://dioo.com/uploads/product/20210528/dae33bc3e6c4b6e07ca730d55ecc4c48.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nDIO706R\n\nsupervisor wdg', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.PASSIVE),
            Pin(num='2',name='V_{CC}',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='PFI',func=pin_types.INPUT),
            Pin(num='5',name='~{PFO}',func=pin_types.OUTPUT),
            Pin(num='6',name='WDI',func=pin_types.INPUT),
            Pin(num='7',name='~{RESET}',func=pin_types.OUTPUT),
            Pin(num='8',name='~{WDO}',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO706S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO706S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisor wdg', 'description':'', 'datasheet':'https://dioo.com/uploads/product/20210528/dae33bc3e6c4b6e07ca730d55ecc4c48.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nDIO706S\n\nsupervisor wdg', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.PASSIVE),
            Pin(num='2',name='V_{CC}',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='PFI',func=pin_types.INPUT),
            Pin(num='5',name='~{PFO}',func=pin_types.OUTPUT),
            Pin(num='6',name='WDI',func=pin_types.INPUT),
            Pin(num='7',name='~{RESET}',func=pin_types.OUTPUT),
            Pin(num='8',name='~{WDO}',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO706T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO706T'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisor wdg', 'description':'', 'datasheet':'https://dioo.com/uploads/product/20210528/dae33bc3e6c4b6e07ca730d55ecc4c48.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nDIO706T\n\nsupervisor wdg', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.PASSIVE),
            Pin(num='2',name='V_{CC}',func=pin_types.PWRIN),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='PFI',func=pin_types.INPUT),
            Pin(num='5',name='~{PFO}',func=pin_types.OUTPUT),
            Pin(num='6',name='WDI',func=pin_types.INPUT),
            Pin(num='7',name='~{RESET}',func=pin_types.OUTPUT),
            Pin(num='8',name='~{WDO}',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6371', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6371'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-8', 'Package_TO_SOT_SMD:SOT-23-8'], 'footprint':'Package_TO_SOT_SMD:SOT-23-8', 'keywords':'watchdog supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6369-MAX6374.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX6371\n\nwatchdog supervisor', 'pins':[
            Pin(num='1',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SET0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{WDO}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6372', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6372'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-8', 'Package_TO_SOT_SMD:SOT-23-8'], 'footprint':'Package_TO_SOT_SMD:SOT-23-8', 'keywords':'watchdog supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6369-MAX6374.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX6372\n\nwatchdog supervisor', 'pins':[
            Pin(num='1',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SET0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{WDO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6373'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-8', 'Package_TO_SOT_SMD:SOT-23-8', 'Package_TO_SOT_SMD:SOT-23-8'], 'footprint':'Package_TO_SOT_SMD:SOT-23-8', 'keywords':'watchdog supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6369-MAX6374.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX6373\n\nwatchdog supervisor', 'pins':[
            Pin(num='1',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SET0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{WDO}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6374'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-8', 'Package_TO_SOT_SMD:SOT-23-8', 'Package_TO_SOT_SMD:SOT-23-8'], 'footprint':'Package_TO_SOT_SMD:SOT-23-8', 'keywords':'watchdog supervisor', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX6369-MAX6374.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX6374\n\nwatchdog supervisor', 'pins':[
            Pin(num='1',name='WDI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SET0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SET1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SET2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{WDO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX811LEUS-T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX811LEUS-T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX811-MAX812.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX811LEUS-T\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX811MEUS-T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX811MEUS-T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX811-MAX812.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX811MEUS-T\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX811REUS-T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX811REUS-T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX811-MAX812.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX811REUS-T\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX811SEUS-T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX811SEUS-T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX811-MAX812.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX811SEUS-T\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX811TEUS-T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX811TEUS-T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX811-MAX812.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMAX811TEUS-T\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP100-300D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP100-300D'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP100-300D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP100-315D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP100-315D'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP100-315D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP100-450D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP100-450D'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP100-450D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP100-460D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP100-460D'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP100-460D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP100-475D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP100-475D'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP100-475D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP100-485D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP100-485D'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP100-485D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP101-300D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP101-300D'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP101-300D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP101-315D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP101-315D'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP101-315D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP101-450D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP101-450D'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP101-450D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP101-460D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP101-460D'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP101-460D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP101-475D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP101-475D'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP101-475D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP101-485D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP101-485D'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'supervisor reset push-pull', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11187f.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP101-485D\n\nsupervisor reset push-pull', 'pins':[
            Pin(num='1',name='RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP130-xxxDxTO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP130-xxxDxTO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'supervisory circuit pull-up', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP130-xxxDxTO\n\nsupervisory circuit pull-up', 'pins':[
            Pin(num='2',name='VDD',func=pin_types.PWRIN),
            Pin(num='1',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP130-xxxHxTO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP130-xxxHxTO'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-92_Inline', 'Package_TO_SOT_THT:TO-92_Inline'], 'footprint':'Package_TO_SOT_THT:TO-92_Inline', 'keywords':'supervisory circuit pull-up', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP130-xxxHxTO\n\nsupervisory circuit pull-up', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP130-xxxxSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP130-xxxxSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'supervisory circuit pull-up', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP130-xxxxSN\n\nsupervisory circuit pull-up', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP130-xxxxTT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP130-xxxxTT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'supervisory circuit pull-up', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/11184d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMCP130-xxxxTT\n\nsupervisory circuit pull-up', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC811JUY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC811JUY'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic811.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMIC811JUY\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC811MUY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC811MUY'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic811.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMIC811MUY\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC811RUY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC811RUY'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic811.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMIC811RUY\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC811SUY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC811SUY'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic811.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMIC811SUY\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC811TUY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC811TUY'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143', 'Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Supervisor Reset', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic811.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nMIC811TUY\n\nSupervisor Reset', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7702B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7702B'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705b.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7702B\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7705A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7705A'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7705A\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7705B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7705B'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705b.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7705B\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7709A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7709A'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7709A\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7712A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7712A'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7712A\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7715A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7715A'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7715A\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL7733B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL7733B'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'voltage supervisor', 'description':'', 'datasheet':'http://www.ti.com.cn/cn/lit/ds/symlink/tl7705b.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTL7733B\n\nvoltage supervisor', 'pins':[
            Pin(num='1',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESIN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RESET',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV810EA29DBZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV810EA29DBZ'}), 'ref_prefix':'U', 'fplist':['', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'', 'keywords':'voltage supervisor low power small size', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv803e.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Supervisor.kicad_sym\nTLV810EA29DBZ\n\nvoltage supervisor low power small size', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RESET',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Dialog = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'DA14691', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DA14691'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-86_6x6mm_Layout10x10_P0.55mm_Ball0.25mm_Pad0.2mm'], 'footprint':'Package_BGA:VFBGA-86_6x6mm_Layout10x10_P0.55mm_Ball0.25mm_Pad0.2mm', 'keywords':'BLE MCU', 'description':'', 'datasheet':'https://www.dialog-semiconductor.com/sites/default/files/da1469x_datasheet_3v1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Dialog.kicad_sym\nDA14691\n\nBLE MCU', 'pins':[
            Pin(num='A1',name='QSPIF_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='A10',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='QSPIF_D0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='P0_10/M33_SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P0_12/CMAC_SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSUP_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='RF_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='RFIOP',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='QSPIF_CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='B10',name='P0_06',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='QSPIF_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P0_11/M33_SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P0_13/CMAC_SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P0_09',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='P0_07',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='QSPIF_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='P0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='QSPIF_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='P0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='P0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='P0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P0_05',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='P0_00',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='P0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='P0_08',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='P0_04',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='XTAL32M_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='P0_03',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='P1_05',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P1_03',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='P1_01',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='P1_00',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P0_02',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='XTAL32M_M',func=pin_types.OUTPUT,unit=1),
            Pin(num='F2',name='P0_01',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSIOQ',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='P1_07',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='XTAL32M_P',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='V18F',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='P0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='V18P',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='P1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='P0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='P1_09',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='V14',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='P0_23/XTAL_32K_P',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='V18',func=pin_types.PWROUT,unit=1),
            Pin(num='H3',name='P1_04',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='P0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='P0_26',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='P0_25',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='P0_22/XTAL_32K_M',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='LY',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='P1_02',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='V12',func=pin_types.PWROUT,unit=1),
            Pin(num='J3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J5',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='V30',func=pin_types.PWROUT,unit=1),
            Pin(num='J7',name='P1_08',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='P1_06',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='P0_24',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='LX',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='VBAT2',func=pin_types.PWROUT,unit=1),
            Pin(num='K3',name='BUCK_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K5',name='VBAT1',func=pin_types.PWROUT,unit=1),
            Pin(num='K6',name='P0_14/USB_P',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='P0_15/USB_M',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='P1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DA14695', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DA14695'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-86_6x6mm_Layout10x10_P0.55mm_Ball0.25mm_Pad0.2mm', 'Package_BGA:VFBGA-86_6x6mm_Layout10x10_P0.55mm_Ball0.25mm_Pad0.2mm'], 'footprint':'Package_BGA:VFBGA-86_6x6mm_Layout10x10_P0.55mm_Ball0.25mm_Pad0.2mm', 'keywords':'BLE MCU', 'description':'', 'datasheet':'https://www.dialog-semiconductor.com/sites/default/files/da1469x_datasheet_3v1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Dialog.kicad_sym\nDA14695\n\nBLE MCU', 'pins':[
            Pin(num='A1',name='QSPIF_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='A10',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='QSPIF_D0',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='P0_10/M33_SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P0_12/CMAC_SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSUP_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='RF_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='RFIOP',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='QSPIF_CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='B10',name='P0_06',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='QSPIF_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P0_11/M33_SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P0_13/CMAC_SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P0_09',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='P0_07',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='QSPIF_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='P0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='QSPIF_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='P0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='P0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='P0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P0_05',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='P0_00',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='P0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='P0_08',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='RF_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='P0_04',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='XTAL32M_GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='P0_03',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='P1_05',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P1_03',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='P1_01',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='P1_00',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P0_02',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='XTAL32M_M',func=pin_types.OUTPUT,unit=1),
            Pin(num='F2',name='P0_01',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSIOQ',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='P1_07',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='XTAL32M_P',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='V18F',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='P0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='V18P',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='P1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='P0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='P1_09',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='V14',func=pin_types.PWROUT,unit=1),
            Pin(num='H10',name='P0_23/XTAL_32K_P',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='V18',func=pin_types.PWROUT,unit=1),
            Pin(num='H3',name='P1_04',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='P0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='P0_26',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='P0_25',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='P0_22/XTAL_32K_M',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='LY',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='P1_02',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='V12',func=pin_types.PWROUT,unit=1),
            Pin(num='J3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J5',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='V30',func=pin_types.PWROUT,unit=1),
            Pin(num='J7',name='P1_08',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='P1_06',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='P0_24',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='LX',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='VBAT2',func=pin_types.PWROUT,unit=1),
            Pin(num='K3',name='BUCK_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K5',name='VBAT1',func=pin_types.PWROUT,unit=1),
            Pin(num='K6',name='P0_14/USB_P',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='P0_15/USB_M',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='P1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])